@@ -1,6 +1,6 @@
-from setup_utils import get_requirements_from_file, do_the_setup, get_version
+from setuptools import find_packages, setup
 
-from setuptools import setup, find_packages  # type: ignore
+from setup_utils import do_the_setup, get_requirements_from_file, get_version
 
 required = get_requirements_from_file("requirements.prod.required.txt")
 required += get_requirements_from_file("requirements.prod.extras.txt")
